.. root-signals documentation master file, created by
   sphinx-quickstart on Mon May 27 13:49:52 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: root_signals+bounding_box.svg
   :height: 200

.. raw:: html

  <p align="center">
    <i>Robust AI Skill Management</i>
  </p>

  <p align="center">
      <a href="https://github.com/root-signals/root-python-sdk/releases">
          <img alt="GitHub release"   src="https://img.shields.io/github/release/root-signals/root-python-sdk.svg">
      </a>
      <a href="https://www.python.org/">
              <img alt="Build"   src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg?color=purple">
      </a>
      <a   href="https://github.com/root-signals/root-python-sdk/blob/master/LICENSE">
          <img alt="License"   src="https://img.shields.io/github/license/rootsignals/roots.svg?color=green">
      </a>
  </p>

This SDK provides a way to use Root Signals cloud service, which helps you
evaluate your LLM pipelines. There are existing tools and frameworks that
help you build these pipelines but evaluating it and quantifying your
pipeline performance can be hard. This is where this comes in.

Root Signals provides you with the tools based on the latest research for
evaluating LLM-generated text to give you insights about your LLM
pipeline. It can be integrated with your CI/CD to provide continuous checks
to ensure performance stays within acceptable limits.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   examples
   setup


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
